@@ -92,9 +92,11 @@ test_that("multiple tables work", {
   skip_on_cran()
   cur <- read_rba(table_no = "a1.1", cur_hist = "current")
   his <- read_rba(table_no = "a1.1", cur_hist = "historical")
-  manual_both <- dplyr::bind_rows(cur, his) %>%
-    dplyr::arrange(series, date)
-  both <- read_rba(table_no = c("a1.1", "a1.1"), cur_hist = c("current", "historical"))
+  manual_both <- dplyr::bind_rows(his, cur) %>%
+    dplyr::arrange(table_title, series, date)
+  both <- read_rba(table_no = c("a1.1", "a1.1"), cur_hist = c("current", "historical")) |>
+    dplyr::arrange(table_title, series, date)
+
 
   expect_identical(
     manual_both,
